@@ -14,6 +14,12 @@ class GitCPP:
             os.chdir(self.git_path)
             subprocess.call(("git %s"%cmd).encode(sys.stdout.encoding), shell=True)
 
+    def changes(self):
+        if self.is_repository():
+            os.chdir(self.git_path)
+
+            return bool(os.popen("git status --porcelain").read())
+
     def commit(self, commit_message):
         self.cmd("add -A")
         self.cmd("commit -m \"%s\""%commit_message)
